:orphan:

Wishlist, TODOs, and Contribution Inspiration
=============================================

Ideally, this should mirror the `issues`_ listed on the ``ramlfications`` `github`_ page.  Ideally.

* Features:
    * ``[ ]`` Add ability to "pluralize" and "singularize" parameters in resourceTypes and traits
    * ``[ ]`` Parse `$ref` in JSON schemas
    * ``[ ]`` Construct RAML via Python objects then `dump`/`dumps` them to file/string output.

.. _`github`: https://github.com/spotify/ramlfications
.. _`issues`: https://github.com/spotify/ramlfications/issues
